@@ -161,10 +161,8 @@ def main():
     if not args.create_networks:
         print(f'Create networks not selected.\n'
               f'If you wish to create networks automatically please set the option -c.\n'
-              f'Otherwise to create networks from previously calculated transformations use the following command '
-              f'from a terminal window:\n'
-              f'> create_networks {args.outdir} '
-              f'{args.metadata_file} {args.group[0]} {args.group[1] if args.group[1] else ""}')
+              f'Otherwise to create networks from previously calculated transformations using the "create_networks"'
+              f'companion script')
         end_time = time.perf_counter()
         print(f'MetaboDirect finished running in {(end_time - start_time) / 60:0.4f} minutes')
         sys.exit()
